@@ -16,24 +16,23 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with logilab-mtconverter. If not, see <http://www.gnu.org/licenses/>.
 
-from six import binary_type
-
 from html2text import html2text
 
 from logilab.mtconverter.transform import Transform
+from logilab.mtconverter import TransformData
 
 
 class html_to_formatted_text(Transform):
     """transforms html to formatted plain text"""
 
     name = "html_to_text"
-    inputs  = ("text/html",)
+    inputs = ("text/html",)
     output = "text/plain"
 
-
-    def _convert(self, trdata):
-        if isinstance(trdata.data, binary_type):
+    def _convert(self, trdata: TransformData) -> bytes:
+        if isinstance(trdata.data, bytes):
             data = trdata.data.decode(trdata.encoding)
         else:
             data = trdata.data
+        assert trdata.encoding is not None
         return html2text(data).encode(trdata.encoding)
